@@ -1,3 +1,5 @@
+import math
+
 import numpy as np
 from AnyQt.QtWidgets import QTreeWidget, QTreeView, QTreeWidgetItem
 
@@ -109,7 +111,8 @@ class OWWordEnrichment(OWWidget):
             self.selected_data_transformed = Table.from_table(
                 self.data.domain, self.selected_data)
 
-            if np_sp_sum(self.selected_data_transformed.X) == 0:
+            sum_X = np_sp_sum(self.selected_data_transformed.X)
+            if sum_X == 0 or math.isnan(sum_X):
                 self.Error.no_words_overlap()
                 self.clear()
             elif len(self.data) == len(self.selected_data):
@@ -136,6 +139,10 @@ class OWWordEnrichment(OWWidget):
         self.spin_p.setEnabled(self.filter_by_p)
         self.spin_fdr.setEnabled(self.filter_by_fdr)
         self.sig_words.clear()
+
+        if self.selected_data_transformed is None:  # do nothing when no Data
+            return
+
         count = 0
         if self.words:
             for word, pval, fval in zip(self.words, self.p_values, self.fdr_values):
